#!/usr/bin/env python2
import rospy
import actionlib
from incredible_package.msg import NumberCrunchingAction, NumberCrunchingGoal, NumberCrunchingResult


def done_cb(success_code, msg):
    """This callback is called then the action has stopped

    Arguments:
        success_code -- code of the success
            - this depends on whether the action succeeded, failed, or was preempted
        msg {NumberCrunchingResult} -- the result of the action
    """
    print("Success code: {}, result: {}".format(success_code, msg))


def active_cb():
    """
    This callback is called when the action started.
    """
    print("Action time!")


def feedback_cb(msg):
    """
    Feed back callback
    """
    print(msg)


if __name__ == '__main__':
    rospy.init_node('action_client')
    # create action client (like the service proxy)
    client = actionlib.SimpleActionClient('number_cruncher',
                                          NumberCrunchingAction)
    client.wait_for_server()  # wait till the action server is up

    goal = NumberCrunchingGoal([1, 2, 3], 10, 1)  # create a goal -> request

    """
    There are two (or more) ways how to call the action.
    You can simply send the goal and wait for the result
    (using "client.wait_for_result()") or you can call the action
    and specify callbacks for the various messages sent from the server.
    Most importantly, you need the "done callback" to know when
    the action is done (or failed).
    In the former case, you can get the result (response) from the client
    using the "client.get_result()" function.
    """
    # client.send_goal(goal)
    client.send_goal(goal, done_cb, active_cb, feedback_cb)
    client.wait_for_result()
    # print(client.get_result())
