#!/usr/bin/env python2
"""
ROS custom message publisher
"""
import rospy  # import rospy, as always
"""
Next import imports our custom message from this package.
The structure of the import:
from <some_package>.<message_definition_folder> import <message_name>
Traditionally, the message folder is called "msg".
You do not have to import from the same package as you are currently in.
For example, the simple "from std_msgs.msg import Float32"
is importing the Float32 message definition from package called "std_msgs".
You can lookup the package and the definition yourself.
If you are interested, what is actually being imported is, of course,
not the text file we created but some custom code to handle the message data
that was built when we ran "catkin build" on this package.
Anyway, let's import our message definition.
"""
from incredible_package.msg import AGoodMessage
from numpy.random import rand  # just to be able to generate random numbers

if __name__ == '__main__':
    rospy.init_node('publisher')  # initialize node with the name "publisher"
    rate = rospy.Rate(1)  # instantiate Rate class with the frequency of 1 Hz
    # Next, create instance of the Publisher class.
    # Set the topic name to "messages" and data type will be our custom message
    publisher = rospy.Publisher('messages',
                                AGoodMessage, queue_size=10)

    while not rospy.is_shutdown():
        msg = AGoodMessage()  # construct a new empty message
        msg.header.stamp = rospy.Time.now()  # fill out the header "timestamp"
        msg.message = 'Hello'  # put some text into the message's "message" field
        msg.number = rand()  # put som random number into the "number" field
        publisher.publish(msg)  # send the message into the topic (data channel)
        rate.sleep()  # pause the code execution for a bit
